<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="en_US">
<context>
    <name>Aide</name>
    <message>
        <location filename="../Ui_help.py" line="144"/>
        <source>Aide</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="143"/>
        <source>Mode d&apos;emploi</source>
        <translation>Usage</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="145"/>
        <source>ScolaSync, pour gerer les fichiers des baladeurs</source>
        <translation>Scolasync, to manage files in pluggable media</translation>
    </message>
    <message>
        <location filename="" line="7274458"/>
        <source>Numero de version&#xa0;:</source>
        <translation type="obsolete">Version number:</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="147"/>
        <source>Auteurs</source>
        <translation>Authors</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="148"/>
        <source>Licence</source>
        <translation>License</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="149"/>
        <source>Langues et traductions</source>
        <translation>Languages and translations</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="150"/>
        <source>A propos</source>
        <translation>About</translation>
    </message>
    <message>
        <location filename="../Ui_help.py" line="151"/>
        <source>Fermer</source>
        <translation>Close</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_help.py" line="146"/>
        <source>Numero de version :</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="" line="7274304"/>
        <source>Choix des fichiers &#xe0; copier</source>
        <translation type="obsolete">Choose files to copy</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="175"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="176"/>
        <source>Ordinateur</source>
        <translation>Desktop/Laptop</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="178"/>
        <source>Disque dur</source>
        <translation>Hard disk</translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="157"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="" line="7274310"/>
        <source>R&#xe9;pertoire de destination des baladeurs</source>
        <translation type="obsolete">Destination directory in the pluggable media</translation>
    </message>
    <message>
        <location filename="" line="7274310"/>
        <source>R&#xe9;pertoire de destination sur les baladeurs,&lt;br&gt;peut &#xea;tre modifi&#xe9; dans les pr&#xe9;f&#xe9;rences</source>
        <translation type="obsolete">Destination directory,&lt;br&gt;can be modified in the preferences</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="184"/>
        <source>Baladeur</source>
        <translation>Puggable device</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="187"/>
        <source>Disque flash</source>
        <translation>Flash disk</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="190"/>
        <source>Cle USB</source>
        <translation>USB stick</translation>
    </message>
    <message>
        <location filename="" line="7274388"/>
        <source>Taille totale&#xa0;:</source>
        <translation type="obsolete">Total size:</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="194"/>
        <source>Ajouter a la liste</source>
        <translation>Add to the list</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="197"/>
        <source>Retirer de la liste</source>
        <translation>Remove from the list</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="199"/>
        <source>Abandonner</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../Ui_copyToDialog1.py" line="200"/>
        <source>Continuer ...</source>
        <translation>Continue...</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="154"/>
        <source>Double-clic non pris en compte</source>
        <translation>Double click is ignored</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="154"/>
        <source>pas d&apos;action pour l&apos;attribut %1</source>
        <translation>No action for attribute &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="" line="7274270"/>
        <source>Choix de fichiers &#xe0; supprimer</source>
        <translation type="obsolete">Choose files to delete</translation>
    </message>
    <message>
        <location filename="" line="7274270"/>
        <source>Choix de fichiers &#xe0; supprimer (jokers autoris&#xe9;s)</source>
        <translation type="obsolete">Choose files to delete (wildcards are OK)</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Aucun fichier s&#xe9;lectionn&#xe9;</source>
        <translation type="obsolete">No selected file</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="285"/>
        <source>Veuillez choisir au moins un fichier</source>
        <translation>Please choose at least one file</translation>
    </message>
    <message>
        <location filename="" line="7274030"/>
        <source>Choix de fichiers &#xe0; copier</source>
        <translation type="obsolete">Choose files to copy</translation>
    </message>
    <message>
        <location filename="" line="7274030"/>
        <source>Choix de fichiers &#xe0; copier depuis les baladeurs</source>
        <translation type="obsolete">Choose files to copy from the pluggable media</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="281"/>
        <source>Choix de la destination ...</source>
        <translation>Choose destination...</translation>
    </message>
    <message>
        <location filename="" line="7274038"/>
        <source>Choisir un r&#xe9;pertoire de destination</source>
        <translation type="obsolete">Choose a destination directory</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="312"/>
        <source>Voir les copies</source>
        <translation>See the copies</translation>
    </message>
    <message>
        <location filename="" line="7273976"/>
        <source>Voulez-vous voir les fichiers copi&#xe9;s&#xa0;?</source>
        <translation type="obsolete">Do you want to see the copied files?</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="317"/>
        <source>Destination manquante</source>
        <translation>Missing destination</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="317"/>
        <source>Veuillez choisir une destination pour la copie des fichiers</source>
        <translation>Please choose a destination to copy the files</translation>
    </message>
    <message>
        <location filename="" line="7273966"/>
        <source>Liste de p&#xe9;riph&#xe9;riques modifi&#xe9;e pour Scolasync</source>
        <translation type="obsolete">Device list modified for Scolasyn</translation>
    </message>
    <message>
        <location filename="" line="7273966"/>
        <source>Une cl&#xe9; USB ou un baladeur num&#xe9;rique au moins a change de statut. V&#xe9;rifiez &#xe9;ventuellement la liste des p&#xe9;riph&#xe9;riques de Scolasync</source>
        <translation type="obsolete">At least one USB stick or music player has chaged its status; eventually check the list of devices of Scolasync</translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="131"/>
        <source>Zone de recherche</source>
        <translation>Search zone</translation>
    </message>
    <message>
        <location filename="" line="7274512"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;R&#xe9;pertoire des &lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;documents de &lt;br /&gt;travail&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Directory of the&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;work documents&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="" line="7274512"/>
        <source>Le r&#xe9;pertoire des cl&#xe9;s&lt;br&gt;o&#xf9; se trouvent les&lt;br&gt;documents de travail</source>
        <translation type="obsolete">Les direstory of the media&lt;br&gt;where the work&lt;br&gt;documents are</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Le r&#xe9;pertoire des cl&#xe9;s o&#xf9; se trouvent les documents de travail</source>
        <translation type="obsolete">The directory of the media where the work documents are</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Choix de cl&#xe9; mod&#xe8;le</source>
        <translation type="obsolete">Choose model pluggable medium</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Choisir une des cl&#xe9;s</source>
        <translation type="obsolete">Choose one pluggable medium</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Liste de fichiers &#xe0; traiter (jokers autoris&#xe9;s)</source>
        <translation type="obsolete">List of files to manage (wildcards are OK)</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Supprimer l&apos;item s&#xe9;lectionn&#xe9;</source>
        <translation type="obsolete">Delete the selected item</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&#xc9;crire le nom d&apos;un fichier ou d&apos;un r&#xe9;pertoire.&lt;br&gt;Jokers autoris&#xe9;s</source>
        <translation type="obsolete">Write the name of a file or a directory&lt;br&gt;wildcards are OK</translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="150"/>
        <source>Ajouter un fichier ou un filtre</source>
        <translation>Add a filename or a filter</translation>
    </message>
    <message>
        <location filename="../Ui_chooseInSticks.py" line="153"/>
        <source>Rechercher (fichier) ...</source>
        <translation>Search (file)...</translation>
    </message>
    <message>
        <location filename="" line="7274332"/>
        <source>Rechercher (r&#xe9;pertoire) ...</source>
        <translation type="obsolete">Search (directory)...</translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="57"/>
        <source>Preferences de ScolaSync</source>
        <translation>Preferences of Scolasync</translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="58"/>
        <source>Preferences</source>
        <translation>Preferences</translation>
    </message>
    <message>
        <location filename="" line="7274524"/>
        <source>Les cases &#xe0; cocher permettent de n&apos;agir que sur une part des baladeurs</source>
        <translation type="obsolete">Checkboxes allow to deal with a subset of the pluggable media</translation>
    </message>
    <message>
        <location filename="" line="7274524"/>
        <source>Utiliser des cases &#xe0; cocher pour d&#xe9;signer les baladeurs</source>
        <translation type="obsolete">Use checkboxes to select pluggable media</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>R&#xe9;pertoire pour les travaux&#xa0;:</source>
        <translation type="obsolete">Directory for the homeworks:</translation>
    </message>
    <message>
        <location filename="../Ui_preferences.py" line="63"/>
        <source>Travail</source>
        <translation>Homework</translation>
    </message>
    <message>
        <location filename="../copyToDialog1.py" line="162"/>
        <source>%s kilo-octets</source>
        <translation>%S kBytes</translation>
    </message>
    <message>
        <location filename="" line="7274256"/>
        <source>%s m&#xe9;ga-octets</source>
        <translation type="obsolete">%s MBytes</translation>
    </message>
    <message>
        <location filename="../copyToDialog1.py" line="168"/>
        <source>%s giga-octets</source>
        <translation>%s GBytes</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="161"/>
        <source>inconnu</source>
        <translation>**unknown**</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="202"/>
        <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
        <translation>The medium %1&lt;br&gt;is unknown, please give the owner&apos;s name</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="203"/>
        <source>Entrer un nom</source>
        <translation>Enter a name</translation>
    </message>
    <message>
        <location filename="../mainWindow.py" line="243"/>
        <source>Vous allez effacer plusieurs baladeurs</source>
        <translation>You will erase many drives</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="60"/>
        <source>Les cases à cocher permettent de n&apos;agir que sur une part des baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="61"/>
        <source>Utiliser des cases à cocher pour désigner les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_preferences.py" line="62"/>
        <source>Répertoire pour les travaux :</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="130"/>
        <source>Choix de fichiers à supprimer</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="132"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Répertoire des &lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;documents de &lt;br /&gt;travail&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="138"/>
        <source>Le répertoire des clés&lt;br&gt;où se trouvent les&lt;br&gt;documents de travail</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="139"/>
        <source>Le répertoire des clés où se trouvent les documents de travail</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="140"/>
        <source>Choix de clé modèle</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="142"/>
        <source>Choisir une des clés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="143"/>
        <source>Liste de fichiers à traiter (jokers autorisés)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="145"/>
        <source>Supprimer l&apos;item sélectionné</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="148"/>
        <source>Écrire le nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_chooseInSticks.py" line="156"/>
        <source>Rechercher (répertoire) ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="174"/>
        <source>Choix des fichiers à copier</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="180"/>
        <source>Répertoire de destination des baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="182"/>
        <source>Répertoire de destination sur les baladeurs,&lt;br&gt;peut être modifié dans les préférences</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_copyToDialog1.py" line="192"/>
        <source>Taille totale :</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../copyToDialog1.py" line="165"/>
        <source>%s méga-octets</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="238"/>
        <source>Choix de fichiers à supprimer (jokers autorisés)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="285"/>
        <source>Aucun fichier sélectionné</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="279"/>
        <source>Choix de fichiers à copier</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="280"/>
        <source>Choix de fichiers à copier depuis les baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="293"/>
        <source>Choisir un répertoire de destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="312"/>
        <source>Voulez-vous voir les fichiers copiés ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context encoding="UTF-8">
    <name>Main</name>
    <message>
        <location filename="../copyToDialog1.py" line="7274244"/>
        <source>D&#xe9;montage des baladeurs</source>
        <translation type="obsolete">Unmount the pluggable media</translation>
    </message>
    <message>
        <location filename="../copyToDialog1.py" line="7274244"/>
        <source>&#xca;tes-vous s&#xfb;r de vouloir d&#xe9;monter tous les baladeurs coch&#xe9;s de la liste&#xa0;?</source>
        <translation type="obsolete">Do you really want to unmount all the pluggable media checked in the list?</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Cocher ou d&#xe9;cocher cette case en cliquant.</source>
        <translation type="obsolete">Chex or uncheck this box by clicking.</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Propri&#xe9;taire de la cl&#xe9; USB ou du baladeur&#xa0;;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
        <translation type="obsolete">Owner of the pluggable medium;&lt;br&gt;&lt;b&gt;Double click&lt;/b&gt; to modify.</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Point de montage de la cl&#xe9; USB ou du baladeur&#xa0;;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
        <translation type="obsolete">Mount point of the pluggable medium;&lt;br&gt;&lt;b&gt;Double click&lt;/b&gt; to see the files.</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Capacit&#xe9; de la cl&#xe9; USB ou du baladeur en kO&#xa0;;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occup&#xe9;e.</source>
        <translation type="obsolete">Size of the pluggable medium;&lt;br&gt;&lt;b&gt;Double click&lt;/b&gt; to see the used place.</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Fabricant de la cl&#xe9; USB ou du baladeur.</source>
        <translation type="obsolete">Manufacturer of the pluggable medium.</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Mod&#xe8;le de la cl&#xe9; USB ou du baladeur.</source>
        <translation type="obsolete">Model of the pluggable medium.</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Num&#xe9;ro de s&#xe9;rie de la cl&#xe9; USB ou du baladeur.</source>
        <translation type="obsolete">Serial number of the pluggable medium.</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Version num&#xe9;ro %1.%2</source>
        <translation type="obsolete">Version #%1.%2</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="337"/>
        <source>Démontage des baladeurs</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="337"/>
        <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="477"/>
        <source>Cocher ou décocher cette case en cliquant.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="479"/>
        <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="481"/>
        <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="483"/>
        <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="485"/>
        <source>Fabricant de la clé USB ou du baladeur.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="487"/>
        <source>Modèle de la clé USB ou du baladeur.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../mainWindow.py" line="489"/>
        <source>Numéro de série de la clé USB ou du baladeur.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../help.py" line="39"/>
        <source>Version numéro %1.%2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../Ui_diskFull.py" line="56"/>
        <source>Disk size</source>
        <translation>Disk size</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../Ui_diskFull.py" line="58"/>
        <source>total size</source>
        <translation>total size</translation>
    </message>
    <message>
        <location filename="../Ui_diskFull.py" line="59"/>
        <source>Used</source>
        <translation>Used</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="119"/>
        <source>ScolaSync</source>
        <translation>Scolasync</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="120"/>
        <source>Actions</source>
        <translation>Actions</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="35"/>
        <source>Copier depuis les cles</source>
        <translation type="obsolete">Copy from the pluggable media</translation>
    </message>
    <message>
        <location filename="" line="5"/>
        <source>Copier vers les cles</source>
        <translation type="obsolete">Copy to the pluggable media</translation>
    </message>
    <message>
        <location filename="" line="7274514"/>
        <source>Supprimer dans les cl&#xe9;s</source>
        <translation type="obsolete">Delete in the pluggable media</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Demonter les cles</source>
        <translation type="obsolete">Unmount the pluggable media</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Preferences</source>
        <translation type="obsolete">Preferences</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="142"/>
        <source>Aide</source>
        <translation>Help</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="137"/>
        <source>Force à recompter les baladeurs</source>
        <translation>Force medias count</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="140"/>
        <source>Affiche le nombre de baladeurs connectés</source>
        <translation>Displays medias count</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="122"/>
        <source>Copier depuis les baladeurs</source>
        <translation>Copy from medias</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="125"/>
        <source>Copier vers les baladeurs</source>
        <translation>Copy to medias</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="128"/>
        <source>Effacer des fichiers ou des dossiers dans les baladeurs</source>
        <translation>Delete files or directories in medias</translation>
    </message>
    <message>
        <location filename="../Ui_mainWindow.py" line="131"/>
        <source>Demonter les baladeurs</source>
        <translation>Unmount medias</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../Ui_mainWindow.py" line="134"/>
        <source>Préférences</source>
        <translation>Preferences</translation>
    </message>
</context>
<context>
    <name>diskFull</name>
    <message>
        <location filename="" line="7274400"/>
        <source>Place totale&#xa0;: %1 kilo-octets</source>
        <translation type="obsolete">Total size: %1 kBytes</translation>
    </message>
    <message>
        <location filename="" line="7274400"/>
        <source>Place utilis&#xe9;e&#xa0;: %1 kilo-octets</source>
        <translation type="obsolete">Used size: %1 kBytes</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../diskFull.py" line="49"/>
        <source>Place totale : %1 kilo-octets</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../diskFull.py" line="50"/>
        <source>Place utilisée : %1 kilo-octets</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>uDisk</name>
    <message>
        <location filename="../usbDisk.py" line="63"/>
        <source>point de montage</source>
        <translation>Mount point</translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="64"/>
        <source>taille</source>
        <translation>Size</translation>
    </message>
    <message>
        <location filename="" line="1"/>
        <source>vendeur</source>
        <translation type="obsolete">Vendor</translation>
    </message>
    <message>
        <location filename="" line="7274450"/>
        <source>mod&#xe8;le de disque</source>
        <translation type="obsolete">Disk model</translation>
    </message>
    <message>
        <location filename="" line="7274450"/>
        <source>num&#xe9;ro de s&#xe9;rie</source>
        <translation type="obsolete">Serial number</translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="70"/>
        <source>cocher</source>
        <translation>Check</translation>
    </message>
    <message>
        <location filename="../ownedUsbDisk.py" line="145"/>
        <source>owner</source>
        <translation>Owner</translation>
    </message>
    <message>
        <location filename="../usbDisk.py" line="65"/>
        <source>marque</source>
        <translation>vendor</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../usbDisk.py" line="66"/>
        <source>modèle de disque</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../usbDisk.py" line="67"/>
        <source>numéro de série</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
